/*****************************************************************************
*               beosconf.h
*
*  This header file contains all constants and types required to run on a
*  BeOS system (much like unix).
*
*  from Persistence of Vision Raytracer
*  Copyright 1995 Persistence of Vision Team
*---------------------------------------------------------------------------
*  NOTICE: This source code file is provided so that users may experiment
*  with enhancements to POV-Ray and to port the software to platforms other
*  than those supported by the POV-Ray Team.  There are strict rules under
*  which you are permitted to use this file.  The rules are in the file
*  named POVLEGAL.DOC which should be distributed with this file. If
*  POVLEGAL.DOC is not available or for more info please contact the POV-Ray
*  Team Coordinator by leaving a message in CompuServe's Graphics Developer's
*  Forum.  The latest version of POV-Ray may be found there as well.
*
* This program is based on the popular DKB raytracer version 2.12.
* DKBTrace was originally written by David K. Buck.
* DKBTrace Ver 2.0-2.12 were written by David K. Buck & Aaron A. Collins.
*
*****************************************************************************/

/* Below are several defines needed by the generic parts of POV.  You
*   may redefine them as needed in this config.h file.
*
*   The following constants are needed by various POV modules.  Each has
*   a default (shown below) which is will be defined in frame.h if you don't
*   define them here.
*
*   #define EPSILON 1.0e-10               - a small value used for POLY
*   #define FILE_NAME_LENGTH 150          - default file name length
*   #define HUGE_VAL 1.0e+17              - a really big number
*   #define DBL_FORMAT_STRING "%lf"       - the string to use for scanfs of doubles
*   #define DEFAULT_OUTPUT_FORMAT  't'    - the default +f format
*   #define FILENAME_SEPARATOR "/"        - the character that separates names
*                                           in a path.
*   #define READ_FILE_STRING "rb"        - special binary (raw, uncooked)
*   #define WRITE_FILE_STRING "wb"         modes of fopen()
*   #define APPEND_FILE_STRING "ab"
*
*   #define DELETE_FILE(name) unlink(name) - function called to delete a file
*   #define DELETE_FILE_ERR -1           - returned by DELETE_FILE on error
*   #define RENAME_FILE(orig,new) rename(orig,new)  - function to rename a file
*   #define RENAME_FILE_ERR -1           - returned by RENAME_FILE on error
*
*   #define NORMAL '0'                   - machine-specific PaletteOption settings
*   #define GREY   'G'
*
*   These routines are required by POV to compute trace times.  The defaults
*   shown below are defined in most versions of C.  You may redefine them if
*   your compiler doesn't support these.  If time is completely unsupported
*   define them as 0.
*
*   #define START_TIME time(&tstart);
*   #define STOP_TIME  time(&tstop);
*   #define TIME_ELAPSED difftime (tstop, tstart);
*
*   Note difftime can be replaced with: #define TIME_ELAPSED (tstop - tstart);
*   in some cases.
*
*   These are optional routines that POV calls.  You may define them
*   or if undefined they will be defined as empty in frame.h.
*
*   #define STARTUP_POVRAY             - first executable statement of main
*                                           (useful for initialization)
*   #define PRINT_OTHER_CREDITS           - used for people who extend the
*                                           machine specific modules
*                                           (put your own printf's here)
*   #define TEST_ABORT                    - code to test for ^C or abort
*                                           (called on each pixel)
*   #define FINISH_POVRAY              - last statement before exiting normally
*   #define COOPERATE                    - called for multi-tasking
*
*   These items are standard on some C compilers.  If they are not defined
*   on your compiler or are called something different you may define your
*   own or use the defaults supplied in frame.h as shown below.
*
*   #define DBL double                    - floating point precision
*   #define ACOS acos                     - arc cosine of DBL
*   #define SQRT sqrt                     - square root of DBL
*   #define POW pow                       - x to the y power - x, y DBL
*   #define COS cos                       - cosine of DBL
*   #define SIN sin                       - sine of DBL
*   #define labs(x) (long) ((x<0)?-x:x)   - Returns the absolute value of long
*                                           integer x
*   #define max (x,y) ((x<y)?y:x)         - greater of x and y
*
*   #define setvbuf(w,x,y,z)              - some systems don't have setvbuf.
*                                           If not, just define it away - it's
*                                           not critical to the raytracer.  It
*                                           just buffers disk accesses.
*
*   This macro controls prototyping and is required by POV.  Choose one
*   of the two options below or if left undefined it will default to ANSI
*   in frame.h
*
*   #define PARAMS (x) x                  - do ANSI prototyping
*   #define PARAMS (x) ()                 - do K&R non-ANSI prototyping
*
*   These allow command line vs non-command line versions and alternate
*   main routines.  Normally they should be undefined.  Define them 1 if needed.
*   #define ALTMAIN 1
*   #define NOCMDLINE 1
*
*   On some systems, memmove does not exist.  If this is the case, defining
*   the following will cause memcpy to be used instead.
*   #define NO_MEMMOVE
*
*   Different monitors have different brightnesses.  Most PC monitors have
*   a display gamma of 2.2, Macintosh displays have a gamma of 1.8, and some
*   UNIX systems (SGI) have displays with gamma 1.7.  If you know the gamma of
*   your system, you can set it here as a constant, or it can be a function
*   call which returns the current display gamma for those operating systems
*   that know what gamma is (namely Macintosh and SGI).  This can be overridden
*   by the INI file directive Display_Gamma=n.nn
*
*   #define DEFAULT_DISPLAY_GAMMA 2.2     - the gamma of the monitor
****************************************************/

#define PARAMS(x) x

#define EPSILON 1.0e-10

#define POV_NAME_MAX 256
#define FILE_NAME_MAX 512

/* Try to read in the default POV-Ray INI file, in the order:
 * 1) whatever POVINI is pointing to,
 * 2) the file .povrayrc in the user's home directory
 * 3) the file povray.ini in the current directory
 */
#define READ_ENV_VAR \
  if ((Option_String_Ptr = getenv("POVINI")) != NULL) \
    if (!parse_ini_file(Option_String_Ptr)) \
    { \
      Warning(0.0, "Could not find '%s' as specified in POVINI environment.\n",\
              Option_String_Ptr); \
      Option_String_Ptr = NULL; \
    }

#define PROCESS_POVRAY_INI \
  if (Option_String_Ptr==NULL && (Option_String_Ptr = getenv("HOME"))!=NULL) { \
    char ini_name[FILE_NAME_MAX]; \
    strncpy(ini_name, Option_String_Ptr, FILE_NAME_MAX); \
    strncat(ini_name, "/.povrayrc", FILE_NAME_MAX); \
    if (parse_ini_file(ini_name) == FALSE) \
      parse_ini_file("povray.ini"); \
  } else \
    parse_ini_file("povray.ini");


#define DEFAULT_OUTPUT_FORMAT  'n'

#define MEM_STATS 1

/*
 * The BeOS precision timer uses gettimeofday().
 */

#define PRECISION_TIMER_AVAILABLE 1

#define PRECISION_TIMER_INIT
#define PRECISION_TIMER_START BeOS_Timer_Start();
#define PRECISION_TIMER_STOP  BeOS_Timer_Stop();
#define PRECISION_TIMER_COUNT BeOS_Timer_Count();

void BeOS_Timer_Start PARAMS((void));
void BeOS_Timer_Stop  PARAMS((void));
int  BeOS_Timer_Count PARAMS((void));

/*
 * This sets up the signal handler during a rendering so that if CTRL-C is
 * pressed, the normal user abort function is called.
 */
#define POV_PRE_RENDER   BeOS_Abort_Start();
#define POV_PRE_SHUTDOWN BeOS_Abort_Handler(0);
void BeOS_Abort_Start PARAMS((void));
void BeOS_Abort_Handler PARAMS((int signum));
